==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/NumericAngleAxisDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { NumericAxisBaseDescriptionMetadata } from "./NumericAxisBaseDescriptionMetadata";
import { NumericAngleAxisDescription } from "./NumericAngleAxisDescription";
/**
 * @hidden
 */
export let NumericAngleAxisDescriptionMetadata = /*@__PURE__*/ (() => {
    class NumericAngleAxisDescriptionMetadata extends Base {
        static b(a) {
            if (NumericAngleAxisDescriptionMetadata.a == null) {
                NumericAngleAxisDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                NumericAngleAxisDescriptionMetadata.c(NumericAngleAxisDescriptionMetadata.a);
            }
            if (a.j(NumericAngleAxisDescriptionMetadata.a)) {
                return;
            }
            a.y(NumericAngleAxisDescriptionMetadata.a);
        }
        static c(a) {
            NumericAxisBaseDescriptionMetadata.c(a);
            a.item("StartAngleOffset", "Number:double");
        }
        static d(a) {
            NumericAngleAxisDescriptionMetadata.b(a);
            a.aa("NumericAngleAxis", () => new NumericAngleAxisDescription());
            a.z("NumericAngleAxis", NumericAngleAxisDescriptionMetadata.a);
        }
    }
    NumericAngleAxisDescriptionMetadata.$t = /*@__PURE__*/ markType(NumericAngleAxisDescriptionMetadata, 'NumericAngleAxisDescriptionMetadata');
    NumericAngleAxisDescriptionMetadata.a = null;
    return NumericAngleAxisDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/NumericAngleAxisDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { NumericAxisBaseDescriptionMetadata } from "./NumericAxisBaseDescriptionMetadata";
import { NumericAngleAxisDescription } from "./NumericAngleAxisDescription";
/**
 * @hidden
 */
export let NumericAngleAxisDescriptionMetadata = /*@__PURE__*/ (() => {
    class NumericAngleAxisDescriptionMetadata extends Base {
        static b(a) {
            if (NumericAngleAxisDescriptionMetadata.a == null) {
                NumericAngleAxisDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                NumericAngleAxisDescriptionMetadata.c(NumericAngleAxisDescriptionMetadata.a);
            }
            if (a.k(NumericAngleAxisDescriptionMetadata.a)) {
                return;
            }
            a.aa(NumericAngleAxisDescriptionMetadata.a);
        }
        static c(a) {
            NumericAxisBaseDescriptionMetadata.c(a);
            a.item("StartAngleOffset", "Number:double");
        }
        static d(a) {
            NumericAngleAxisDescriptionMetadata.b(a);
            a.ac("NumericAngleAxis", () => new NumericAngleAxisDescription());
            a.ab("NumericAngleAxis", NumericAngleAxisDescriptionMetadata.a);
        }
    }
    NumericAngleAxisDescriptionMetadata.$t = /*@__PURE__*/ markType(NumericAngleAxisDescriptionMetadata, 'NumericAngleAxisDescriptionMetadata');
    NumericAngleAxisDescriptionMetadata.a = null;
    return NumericAngleAxisDescriptionMetadata;
})();
